@@ -196,12 +196,12 @@ test_that("by_row() creates indices with c++ style indexing", {
 
 test_that("error is thrown when no columns to map", {
   expect_error(mtcars["cyl"] %>% slice_rows("cyl") %>% by_slice(list), "empty")
-  expect_error(dplyr::data_frame() %>% invoke_rows(.f = c), "empty")
-  expect_error(dplyr::data_frame() %>% by_row(c), "empty")
+  expect_error(dplyr::tibble() %>% invoke_rows(.f = c), "empty")
+  expect_error(dplyr::tibble() %>% by_row(c), "empty")
 })
 
 test_that("grouping list-columns are copied (#9)", {
-  df <- tibble::tibble(x = as.list(1:2))
-  exp <- tibble::tibble(x = list(1L, 2L), .out = list(NA, NA))
+  df <- dplyr::tibble(x = as.list(1:2))
+  exp <- dplyr::tibble(x = list(1L, 2L), .out = list(NA, NA))
   expect_identical(by_row(df, ~NA), exp)
 })
